==> tw-api-5.0.41-20240716.011639-3-sources.jar: com/elitesland/tw/tw5/api/prd/crm/vo/CrmCustomerSimpleVO.java <==
package com.elitesland.tw.tw5.api.prd.crm.vo;

import lombok.Getter;
import lombok.Setter;

/**
 * @Author carl.wang
 * @Description 客户表
 * @Date
 **/
@Setter
@Getter
public class CrmCustomerSimpleVO {

    private Long id;

    /**
     * 请求来源 示例：销售拜访任务（访销计划任务 sell_visit_plan）
     */
    //private String from;
    /**
     * 地址簿id
     */
    private Long bookId;
    /**
     * 地址簿编号
     */
    private String bookNo;
    /**
     * (激活，暂挂)
     */
    private String customerStatus;
    /**
     * 客户状态(激活，暂挂)
     */
    //private String customerStatusName;
    /**
     * 客户名称
     */
    private String customerName;
    /**
     * 客户级别
     */
    private String customerGrade;
    /**
     * 客户级别
     */
    private String customerGradeName;

    /**
     * 客户来源
     */
    private String customerSource;
    /**
     * 客户来源
     */
    private String customerSourceName;
    /**
     * 客户行业
     */
    //private String companyIndustry;
    ///**
    // * 客户行业
    // */
    //private String companyIndustryName;
    ///**
    // * 电话
    // */
    //private String companyPhone;
    ///**
    // * 邮箱
    // */
    //private String companyEmail;
    ///**
    // * 传真
    // */
    //private String companyFax;
    ///**
    // * 省
    // */
    //private String province;
    ///**
    // * 省
    // */
    //private String provinceName;
    ///**
    // * 市
    // */
    //private String city;
    ///**
    // * 市
    // */
    //private String cityName;
    ///**
    // * 区
    // */
    //private String district;
    ///**
    // * 区
    // */
    //private String districtName;
    /**
     * 详细地址
     */
    private String companyAddress;
    /**
     * 网址
     */
    //private String companyWebsite;
    /**
     * 规模
     */
    //private String companyScale;
    //private String companyScaleName;

    /**
     * 税号
     */
    //private String taxNo;
    ///**
    // * 交易货币
    // */
    //private String currency;
    //private String currencyName;
    ///**
    // * 语言
    // */
    //private String language;
    //private String languageName;
    ///**
    // * 公司性质
    // */
    //private String companyNature;
    //private String companyNatureName;
    ///**
    // * 服务负责人
    // */
    //private Long serviceUserId;
    ///**
    // * 服务负责人
    // */
    //private String serviceUserName;
    ///**
    // * 商务负责人
    // */
    //private Long businessUserId;
    ///**
    // * 商务负责人
    // */
    //private String businessUserName;
    ///**
    // * 关怀负责人
    // */
    //private Long careUserId;
    ///**
    // * 关怀负责人
    // */
    //private String careUserName;
    //
    ///**
    // * 运维售后负责人
    // */
    //private Long operationUserId;
    ///**
    // * 运维售后负责人
    // */
    //private String operationUserName;
    ///**
    // * 创建人
    // */
    //private String createUserName;
    //
    ///**
    // * 客户级别可更改
    // */
    //private Boolean customerGradeEditFlag;
    //
    //
    //private CrmCustomerOperationVO customerOperationVO;
    /**
     * 经纬度
     */
    private String longitudeLatitude;

    /**
     * 业务伙伴id business_partner.id
     */
    private Long partnerId;
}

==> tw-api-5.1.77-20240929.134936-1-sources.jar: com/elitesland/tw/tw5/api/prd/crm/vo/CrmCustomerSimpleVO.java <==
package com.elitesland.tw.tw5.api.prd.crm.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

/**
 * @Author carl.wang
 * @Description 客户表
 * @Date
 **/
@Setter
@Getter
public class CrmCustomerSimpleVO {

    private Long id;

    /**
     * 请求来源 示例：销售拜访任务（访销计划任务 sell_visit_plan）
     */
    //private String from;
    /**
     * 地址簿id
     */
    private Long bookId;
    /**
     * 地址簿编号
     */
    private String bookNo;
    /**
     * (激活，暂挂)
     */
    private String customerStatus;
    /**
     * 客户状态(激活，暂挂)
     */
    //private String customerStatusName;
    /**
     * 客户名称
     */
    private String customerName;
    /**
     * 客户级别
     */
    private String customerGrade;
    /**
     * 客户级别
     */
    private String customerGradeName;

    /**
     * 客户来源
     */
    private String customerSource;
    /**
     * 客户来源
     */
    private String customerSourceName;
    /**
     * 客户行业
     */
    //private String companyIndustry;
    ///**
    // * 客户行业
    // */
    //private String companyIndustryName;
    ///**
    // * 电话
    // */
    //private String companyPhone;
    ///**
    // * 邮箱
    // */
    //private String companyEmail;
    ///**
    // * 传真
    // */
    //private String companyFax;
    ///**
    // * 省
    // */
    //private String province;
    ///**
    // * 省
    // */
    //private String provinceName;
    ///**
    // * 市
    // */
    //private String city;
    ///**
    // * 市
    // */
    //private String cityName;
    ///**
    // * 区
    // */
    //private String district;
    ///**
    // * 区
    // */
    //private String districtName;
    /**
     * 详细地址
     */
    private String companyAddress;
    /**
     * 网址
     */
    //private String companyWebsite;
    /**
     * 规模
     */
    //private String companyScale;
    //private String companyScaleName;

    /**
     * 税号
     */
    //private String taxNo;
    ///**
    // * 交易货币
    // */
    //private String currency;
    //private String currencyName;
    ///**
    // * 语言
    // */
    //private String language;
    //private String languageName;
    ///**
    // * 公司性质
    // */
    //private String companyNature;
    //private String companyNatureName;
    ///**
    // * 服务负责人
    // */
    //private Long serviceUserId;
    ///**
    // * 服务负责人
    // */
    //private String serviceUserName;
    ///**
    // * 商务负责人
    // */
    //private Long businessUserId;
    ///**
    // * 商务负责人
    // */
    //private String businessUserName;
    ///**
    // * 关怀负责人
    // */
    //private Long careUserId;
    ///**
    // * 关怀负责人
    // */
    //private String careUserName;
    //
    ///**
    // * 运维售后负责人
    // */
    //private Long operationUserId;
    ///**
    // * 运维售后负责人
    // */
    //private String operationUserName;
    ///**
    // * 创建人
    // */
    //private String createUserName;
    //
    ///**
    // * 客户级别可更改
    // */
    //private Boolean customerGradeEditFlag;
    //
    //
    //private CrmCustomerOperationVO customerOperationVO;
    /**
     * 经纬度
     */
    private String longitudeLatitude;

    /**
     * 业务伙伴id business_partner.id
     */
    private Long partnerId;


    /**
     * 是否是新客户
     */
    @ApiModelProperty("是否是新客户")
    private Boolean newCustFlag;
}
